@@ -444,6 +444,7 @@ msd_osd_window_init (MsdOsdWindow *window)
 
         if (window->priv->is_composited) {
                 gdouble scalew, scaleh, scale;
+                gint sc_width, sc_height;
                 gint size;
 
                 gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
@@ -453,8 +454,12 @@ msd_osd_window_init (MsdOsdWindow *window)
                 gtk_style_context_add_class (style, "window-frame");
 
                 /* assume 130x130 on a 640x480 display and scale from there */
-                scalew = gdk_screen_get_width (screen) / 640.0;
-                scaleh = gdk_screen_get_height (screen) / 480.0;
+
+                gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+                                         &sc_width, &sc_height);
+
+                scalew = sc_width / 640.0;
+                scaleh = sc_height / 480.0;
                 scale = MIN (scalew, scaleh);
                 size = 130 * MAX (1, scale);
 
